==> haskell-safe-exceptions-0.1.7.0-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-Aa85liCaGz15CrLkVLZzVd
key: safe-exceptions-0.1.7.0-Aa85liCaGz15CrLkVLZzVd
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
abi: 37595ab4f7e68dda95033158d62ecb3c
exposed: True
exposed-modules:
    Control.Exception.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-Aa85liCaGz15CrLkVLZzVd
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.0-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-2B2GLstsQHYIiVve56KNnJ
key: safe-exceptions-0.1.7.0-2B2GLstsQHYIiVve56KNnJ
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
abi: 67013e7402f35c106a5f3db1b3da53ac
exposed: True
exposed-modules:
    Control.Exception.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-2B2GLstsQHYIiVve56KNnJ
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
